==> treeland_0.7.3.tar.xz: BUILD/translations/treeland.sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="29"/>
        <source>Minimize</source>
        <translation>Minimizoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Unmaximize</source>
        <translation>Shmaksimizoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Maximize</source>
        <translation>Maksimizoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="39"/>
        <source>Move</source>
        <translation>Lëvize</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="44"/>
        <source>Resize</source>
        <translation>Ripërmasoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="50"/>
        <source>Always on Top</source>
        <translation>Përherë Në Krye</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="56"/>
        <source>Always on Visible Workspace</source>
        <translation>Përherë në Hapësirë Pune të Dukshme</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="70"/>
        <source>Move to Left Work Space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="77"/>
        <source>Move to Right Work Space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="83"/>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
</context>
</TS>

==> treeland_0.7.8.tar.xz: BUILD/translations/treeland.sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="29"/>
        <source>Minimize</source>
        <translation>Minimizoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Unmaximize</source>
        <translation>Shmaksimizoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="34"/>
        <source>Maximize</source>
        <translation>Maksimizoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="39"/>
        <source>Move</source>
        <translation>Lëvize</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="44"/>
        <source>Resize</source>
        <translation>Ripërmasoje</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="50"/>
        <source>Always on Top</source>
        <translation>Përherë Në Krye</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="56"/>
        <source>Always on Visible Workspace</source>
        <translation>Përherë në Hapësirë Pune të Dukshme</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="70"/>
        <source>Move to Left Work Space</source>
        <translation>Shpjere te Hapësira e Punës Majtas</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="77"/>
        <source>Move to Right Work Space</source>
        <translation>Shpjere te Hapësira e Punës Djathtas</translation>
    </message>
    <message>
        <location filename="../src/core/qml/WindowMenu.qml" line="83"/>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
</context>
</TS>
